local yorsahjID = "D810" --in hex since that's how game gives it
local bloodIDs = {
	["Hspell:104894"] = "1", --Dark
	["Hspell:104900"] = "2", --Cobalt
	["Hspell:105027"] = "2", --Cobalt Maybe heroic version?
	["Hspell:104898"] = "3", --Acidic
	["Hspell:104896"] = "4", --Shadowed
	["Hspell:110748"] = "4", --Shadowed Maybe heroic version?
	["Hspell:104897"] = "5", --Crimson
	["Hspell:104901"] = "6", --Glowing
	["Hspell:108221"] = "6", --Glowing Maybe heroic version?
}

local addonName, addon = ...
LibStub("AceAddon-3.0"):NewAddon(addon, addonName, "AceEvent-3.0")

function addon:OnInitialize()
	self:SetupDB()
	self:SetupOptions()
	self.summonedGlobules = {}
	self:SetEnabledState(self.db.global.enabled)
end

function addon:OnEnable()
	self:RegisterEvent("CHAT_MSG_RAID_BOSS_EMOTE")
end

function addon:CHAT_MSG_RAID_BOSS_EMOTE(event, message)
	local bossGUID = UnitGUID("boss1")
	if not bossGUID then return end --we aren't fighting anything, abort
	if bossGUID:sub(-12, -9) ~= yorsahjID then return end --we aren't fighting yorsahj, abort
	wipe(self.summonedGlobules)
	for spellID, color in pairs(bloodIDs) do
		if message:find(spellID) then
			self.summonedGlobules[#self.summonedGlobules+1] = color
		end
	end
	local numGlobules = #self.summonedGlobules
	if ( numGlobules ~= 3 and numGlobules ~= 4) then return end --didnt find three/four globules, abort (should try to detect heroic mode)
	sort(self.summonedGlobules)
	local summonedGlobulesString = self.summonedGlobules[1]..self.summonedGlobules[2]..self.summonedGlobules[3]
	local mode
	if numGlobules == 4 then
		mode = "heroic"
	else
		if IsInLFGDungeon() then
			mode = "lfr"
		else
			mode = "normal"
		end
	end
	self.killGlobule = self.db.global.priorities[mode][summonedGlobulesString]
	self:OutputWarning()
end
			
function addon:OutputWarning()
	local announceSettings = self.db.global.announces
	if announceSettings.yell then
		SendChatMessage(self.killGlobule, "YELL")
	end
	if announceSettings.raid then
		SendChatMessage(self.killGlobule, "RAID")
	end
	if announceSettings.raidWarning then
		if IsRaidLeader("player") or IsRaidOfficer("player") then
			SendChatMessage(self.killGlobule, "RAID_WARNING")
		end
	end
	if announceSettings.privateRaidWarning then
		RaidNotice_AddMessage(RaidWarningFrame, self.killGlobule, ChatTypeInfo["RAID_WARNING"])
		PlaySoundFile("Sound\\Interface\\RaidWarning.wav")
	end
	if announceSettings.privateChatMessage then
		print(self.killGlobule)
	end
end